@@ -1,14 +1,13 @@
 'use strict';
 
 const path = require('path');
-
-const File = require('./file');
-const FileDescriptor = require('./descriptor');
-const Directory = require('./directory');
-const SymbolicLink = require('./symlink');
-const {FSError} = require('./error');
+const File = require('./file.js');
+const FileDescriptor = require('./descriptor.js');
+const Directory = require('./directory.js');
+const SymbolicLink = require('./symlink.js');
+const {FSError} = require('./error.js');
 const constants = require('constants');
-const getPathParts = require('./filesystem').getPathParts;
+const getPathParts = require('./filesystem.js').getPathParts;
 
 const MODE_TO_KTYPE = {
   [constants.S_IFREG]: constants.UV_DIRENT_FILE,
@@ -17,7 +16,7 @@ const MODE_TO_KTYPE = {
   [constants.S_IFCHR]: constants.UV_DIRENT_CHAR,
   [constants.S_IFLNK]: constants.UV_DIRENT_LINK,
   [constants.S_IFIFO]: constants.UV_DIRENT_FIFO,
-  [constants.S_IFSOCK]: constants.UV_DIRENT_SOCKET
+  [constants.S_IFSOCK]: constants.UV_DIRENT_SOCKET,
 };
 
 /** Workaround for optimizations in node 8+ */
@@ -36,8 +35,8 @@ const MAX_LINKS = 50;
  * Call the provided function and either return the result or call the callback
  * with it (depending on if a callback is provided).
  * @param {function()} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @param {Object} thisArg This argument for the following function.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} thisArg This argument for the following function.
  * @param {function()} func Function to call.
  * @return {*} Return (if callback is not provided).
  */
@@ -52,8 +51,8 @@ function maybeCallback(callback, ctx, thisArg, func) {
     } catch (e) {
       err = e;
     }
-    return new Promise(function(resolve, reject) {
-      process.nextTick(function() {
+    return new Promise(function (resolve, reject) {
+      process.nextTick(function () {
         if (err) {
           reject(err);
         } else {
@@ -67,7 +66,7 @@ function maybeCallback(callback, ctx, thisArg, func) {
     } catch (e) {
       err = e;
     }
-    process.nextTick(function() {
+    process.nextTick(function () {
       if (val === undefined) {
         callback(err);
       } else {
@@ -89,8 +88,8 @@ function maybeCallback(callback, ctx, thisArg, func) {
 
 /**
  * set syscall property on context object, only for nodejs v10+.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @param {String} syscall Name of syscall.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @param {string} syscall Name of syscall.
  */
 function markSyscall(ctx, syscall) {
   if (ctx && typeof ctx === 'object') {
@@ -132,7 +131,7 @@ function deBuffer(p) {
 /**
  * Create a new binding with the given file system.
  * @param {FileSystem} system Mock file system.
- * @constructor
+ * @class
  */
 function Binding(system) {
   /**
@@ -143,7 +142,7 @@ function Binding(system) {
 
   /**
    * Lookup of open files.
-   * @type {Object.<number, FileDescriptor>}
+   * @type {Object<number, FileDescriptor>}
    */
   this._openFiles = {};
 
@@ -170,7 +169,7 @@ function Binding(system) {
  * Get the file system underlying this binding.
  * @return {FileSystem} The underlying file system.
  */
-Binding.prototype.getSystem = function() {
+Binding.prototype.getSystem = function () {
   return this._system;
 };
 
@@ -178,7 +177,7 @@ Binding.prototype.getSystem = function() {
  * Reset the file system underlying this binding.
  * @param {FileSystem} system The new file system.
  */
-Binding.prototype.setSystem = function(system) {
+Binding.prototype.setSystem = function (system) {
   this._system = system;
 };
 
@@ -187,7 +186,7 @@ Binding.prototype.setSystem = function(system) {
  * @param {number} fd File descriptor identifier.
  * @return {FileDescriptor} File descriptor.
  */
-Binding.prototype.getDescriptorById = function(fd) {
+Binding.prototype.getDescriptorById = function (fd) {
   if (!this._openFiles.hasOwnProperty(fd)) {
     throw new FSError('EBADF');
   }
@@ -199,7 +198,7 @@ Binding.prototype.getDescriptorById = function(fd) {
  * @param {FileDescriptor} descriptor The file descriptor.
  * @return {number} Identifier for file descriptor.
  */
-Binding.prototype.trackDescriptor = function(descriptor) {
+Binding.prototype.trackDescriptor = function (descriptor) {
   const fd = ++this._counter;
   this._openFiles[fd] = descriptor;
   return fd;
@@ -209,7 +208,7 @@ Binding.prototype.trackDescriptor = function(descriptor) {
  * Stop tracking a file descriptor as open.
  * @param {number} fd Identifier for file descriptor.
  */
-Binding.prototype.untrackDescriptorById = function(fd) {
+Binding.prototype.untrackDescriptorById = function (fd) {
   if (!this._openFiles.hasOwnProperty(fd)) {
     throw new FSError('EBADF');
   }
@@ -220,13 +219,14 @@ Binding.prototype.untrackDescriptorById = function(fd) {
  * Resolve the canonicalized absolute pathname.
  * @param {string|Buffer} filepath The file path.
  * @param {string} encoding The encoding for the return.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {Function} callback The callback.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {string|Buffer} The real path.
  */
-Binding.prototype.realpath = function(filepath, encoding, callback, ctx) {
+Binding.prototype.realpath = function (filepath, encoding, callback, ctx) {
   markSyscall(ctx, 'realpath');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     let realPath;
     filepath = deBuffer(filepath);
     const resolved = path.resolve(filepath);
@@ -273,8 +273,8 @@ Binding.prototype.realpath = function(filepath, encoding, callback, ctx) {
   });
 };
 
-function fillStats(stats) {
-  const target = stats instanceof Float64Array ? statValues : bigintStatValues;
+function fillStats(stats, bigint) {
+  const target = bigint ? bigintStatValues : statValues;
   for (let i = 0; i < 36; i++) {
     target[i] = stats[i];
   }
@@ -283,14 +283,15 @@ function fillStats(stats) {
 /**
  * Stat an item.
  * @param {string} filepath Path.
+ * @param {boolean} bigint Use BigInt.
  * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
-Binding.prototype.stat = function(filepath, bigint, callback, ctx) {
+Binding.prototype.stat = function (filepath, bigint, callback, ctx) {
   markSyscall(ctx, 'stat');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     filepath = deBuffer(filepath);
     let item = this._system.getItem(filepath);
     if (item instanceof SymbolicLink) {
@@ -302,7 +303,7 @@ Binding.prototype.stat = function(filepath, bigint, callback, ctx) {
       throw new FSError('ENOENT', filepath);
     }
     const stats = item.getStats(bigint);
-    fillStats(stats);
+    fillStats(stats, bigint);
     return stats;
   });
 };
@@ -310,18 +311,19 @@ Binding.prototype.stat = function(filepath, bigint, callback, ctx) {
 /**
  * Stat an item.
  * @param {number} fd File descriptor.
+ * @param {boolean} bigint Use BigInt.
  * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
-Binding.prototype.fstat = function(fd, bigint, callback, ctx) {
+Binding.prototype.fstat = function (fd, bigint, callback, ctx) {
   markSyscall(ctx, 'fstat');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     const stats = item.getStats(bigint);
-    fillStats(stats);
+    fillStats(stats, bigint);
     return stats;
   });
 };
@@ -330,12 +332,13 @@ Binding.prototype.fstat = function(fd, bigint, callback, ctx) {
  * Close a file descriptor.
  * @param {number} fd File descriptor.
  * @param {function(Error)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback.
  */
-Binding.prototype.close = function(fd, callback, ctx) {
+Binding.prototype.close = function (fd, callback, ctx) {
   markSyscall(ctx, 'close');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     this.untrackDescriptorById(fd);
   });
 };
@@ -346,13 +349,13 @@ Binding.prototype.close = function(fd, callback, ctx) {
  * @param {number} flags Flags.
  * @param {number} mode Mode.
  * @param {function(Error, string)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {string} File descriptor (if sync).
  */
-Binding.prototype.open = function(pathname, flags, mode, callback, ctx) {
+Binding.prototype.open = function (pathname, flags, mode, callback, ctx) {
   markSyscall(ctx, 'open');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const descriptor = new FileDescriptor(flags);
     let item = this._system.getItem(pathname);
@@ -414,19 +417,20 @@ Binding.prototype.open = function(pathname, flags, mode, callback, ctx) {
  * @param {string} pathname File path.
  * @param {number} flags Flags.
  * @param {number} mode Mode.
- * @param {function} callback Callback (optional), expecting kUsePromises in nodejs v10+.
+ * @param {Function} callback Callback (optional), expecting kUsePromises in nodejs v10+.
+ * @return {string} The file handle.
  */
-Binding.prototype.openFileHandle = function(pathname, flags, mode, callback) {
+Binding.prototype.openFileHandle = function (pathname, flags, mode, callback) {
   const self = this;
 
-  return this.open(pathname, flags, mode, kUsePromises).then(function(fd) {
+  return this.open(pathname, flags, mode, kUsePromises).then(function (fd) {
     // nodejs v10+ fs.promises FileHandler constructor only ask these three properties.
     return {
       getAsyncId: notImplemented,
       fd: fd,
-      close: function() {
+      close: function () {
         return self.close(fd, kUsePromises);
-      }
+      },
     };
   });
 };
@@ -441,10 +445,10 @@ Binding.prototype.openFileHandle = function(pathname, flags, mode, callback) {
  *     data will be read from the current file position.
  * @param {function(Error, number, Buffer)} callback Callback (optional) called
  *     with any error, number of bytes read, and the buffer.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {number} Number of bytes read (if sync).
  */
-Binding.prototype.read = function(
+Binding.prototype.read = function (
   fd,
   buffer,
   offset,
@@ -455,7 +459,7 @@ Binding.prototype.read = function(
 ) {
   markSyscall(ctx, 'read');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isRead()) {
       throw new FSError('EBADF');
@@ -487,12 +491,13 @@ Binding.prototype.read = function(
  * @param {number} flags Modifiers for copy operation.
  * @param {function(Error)} callback Callback (optional) called
  *     with any error.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.copyFile = function(src, dest, flags, callback, ctx) {
+Binding.prototype.copyFile = function (src, dest, flags, callback, ctx) {
   markSyscall(ctx, 'copyfile');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     src = deBuffer(src);
     dest = deBuffer(dest);
     const srcFd = this.open(src, constants.O_RDONLY);
@@ -536,10 +541,10 @@ Binding.prototype.copyFile = function(src, dest, flags, callback, ctx) {
  *     data will be written to the current file position.
  * @param {function(Error, number, Buffer)} callback Callback (optional) called
  *     with any error, number of bytes written, and the buffer.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {number} Number of bytes written (if sync).
  */
-Binding.prototype.writeBuffers = function(
+Binding.prototype.writeBuffers = function (
   fd,
   buffers,
   position,
@@ -548,7 +553,7 @@ Binding.prototype.writeBuffers = function(
 ) {
   markSyscall(ctx, 'write');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isWrite()) {
       throw new FSError('EBADF');
@@ -586,10 +591,10 @@ Binding.prototype.writeBuffers = function(
  *     data will be written to the current file position.
  * @param {function(Error, number, Buffer)} callback Callback (optional) called
  *     with any error, number of bytes written, and the buffer.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {number} Number of bytes written (if sync).
  */
-Binding.prototype.writeBuffer = function(
+Binding.prototype.writeBuffer = function (
   fd,
   buffer,
   offset,
@@ -600,7 +605,7 @@ Binding.prototype.writeBuffer = function(
 ) {
   markSyscall(ctx, 'write');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isWrite()) {
       throw new FSError('EBADF');
@@ -642,9 +647,10 @@ Binding.prototype.writeBuffer = function(
  * @param {string} encoding String encoding.
  * @param {function(Error, number, string)} callback Callback (optional) called
  *     with any error, number of bytes written, and the string.
+ * @param {object} ctx The context.
  * @return {number} Number of bytes written (if sync).
  */
-Binding.prototype.writeString = function(
+Binding.prototype.writeString = function (
   fd,
   string,
   position,
@@ -660,7 +666,7 @@ Binding.prototype.writeString = function(
     if (callback.oncomplete) {
       callback = callback.oncomplete.bind(callback);
     }
-    wrapper = function(err, written, returned) {
+    wrapper = function (err, written, returned) {
       callback(err, written, returned && string);
     };
   }
@@ -672,13 +678,13 @@ Binding.prototype.writeString = function(
  * @param {string} oldPath Old pathname.
  * @param {string} newPath New pathname.
  * @param {function(Error)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {undefined}
  */
-Binding.prototype.rename = function(oldPath, newPath, callback, ctx) {
+Binding.prototype.rename = function (oldPath, newPath, callback, ctx) {
   markSyscall(ctx, 'rename');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     oldPath = deBuffer(oldPath);
     newPath = deBuffer(newPath);
     const oldItem = this._system.getItem(oldPath);
@@ -725,10 +731,10 @@ Binding.prototype.rename = function(oldPath, newPath, callback, ctx) {
  * @param {boolean} withFileTypes whether or not to return fs.Dirent objects
  * @param {function(Error, (Array.<string>|Array.<Buffer>)} callback Callback
  *     (optional) called with any error or array of items in the directory.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
- * @return {Array.<string>|Array.<Buffer>} Array of items in directory (if sync).
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {Array<string> | Array<Buffer>} Array of items in directory (if sync).
  */
-Binding.prototype.readdir = function(
+Binding.prototype.readdir = function (
   dirpath,
   encoding,
   withFileTypes,
@@ -737,7 +743,7 @@ Binding.prototype.readdir = function(
 ) {
   markSyscall(ctx, 'scandir');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     dirpath = deBuffer(dirpath);
     let dpath = dirpath;
     let dir = this._system.getItem(dirpath);
@@ -757,13 +763,13 @@ Binding.prototype.readdir = function(
 
     let list = dir.list();
     if (encoding === 'buffer') {
-      list = list.map(function(item) {
+      list = list.map(function (item) {
         return Buffer.from(item);
       });
     }
 
     if (withFileTypes === true) {
-      const types = list.map(function(name) {
+      const types = list.map(function (name) {
         const stats = dir.getItem(name).getStats();
 
         return getDirentType(stats.mode);
@@ -781,12 +787,13 @@ Binding.prototype.readdir = function(
  * @param {number} mode Permissions.
  * @param {boolean} recursive Recursively create deep directory. (added in nodejs v10+)
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.mkdir = function(pathname, mode, recursive, callback, ctx) {
+Binding.prototype.mkdir = function (pathname, mode, recursive, callback, ctx) {
   markSyscall(ctx, 'mkdir');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const item = this._system.getItem(pathname);
     if (item) {
@@ -797,7 +804,7 @@ Binding.prototype.mkdir = function(pathname, mode, recursive, callback, ctx) {
       throw new FSError('EEXIST', pathname);
     }
 
-    const _mkdir = function(_pathname) {
+    const _mkdir = function (_pathname) {
       const parentDir = path.dirname(_pathname);
       let parent = this._system.getItem(parentDir);
       if (!parent) {
@@ -822,12 +829,13 @@ Binding.prototype.mkdir = function(pathname, mode, recursive, callback, ctx) {
  * Remove a directory.
  * @param {string} pathname Path to directory.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.rmdir = function(pathname, callback, ctx) {
+Binding.prototype.rmdir = function (pathname, callback, ctx) {
   markSyscall(ctx, 'rmdir');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const item = this._system.getItem(pathname);
     if (!item) {
@@ -853,12 +861,13 @@ const MAX_ATTEMPTS = 62 * 62 * 62;
 /**
  * Create a directory based on a template.
  * See http://web.mit.edu/freebsd/head/lib/libc/stdio/mktemp.c
- * @param {string} template Path template (trailing Xs will be replaced).
+ * @param {string} prefix Path template (trailing Xs will be replaced).
  * @param {string} encoding The encoding ('utf-8' or 'buffer').
  * @param {function(Error, string)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.mkdtemp = function(prefix, encoding, callback, ctx) {
+Binding.prototype.mkdtemp = function (prefix, encoding, callback, ctx) {
   if (encoding && typeof encoding !== 'string') {
     callback = encoding;
     encoding = 'utf-8';
@@ -866,7 +875,7 @@ Binding.prototype.mkdtemp = function(prefix, encoding, callback, ctx) {
 
   markSyscall(ctx, 'mkdtemp');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     prefix = prefix.replace(/X{0,6}$/, 'XXXXXX');
     const parentPath = path.dirname(prefix);
     const parent = this._system.getItem(parentPath);
@@ -915,12 +924,13 @@ Binding.prototype.mkdtemp = function(prefix, encoding, callback, ctx) {
  * @param {number} fd File descriptor.
  * @param {number} len Number of bytes.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.ftruncate = function(fd, len, callback, ctx) {
+Binding.prototype.ftruncate = function (fd, len, callback, ctx) {
   markSyscall(ctx, 'ftruncate');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     if (!descriptor.isWrite()) {
       throw new FSError('EINVAL');
@@ -941,7 +951,7 @@ Binding.prototype.ftruncate = function(fd, len, callback, ctx) {
  * @param {number} fd File descriptor.
  * @param {number} len Number of bytes.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  */
 Binding.prototype.truncate = Binding.prototype.ftruncate;
 
@@ -951,12 +961,13 @@ Binding.prototype.truncate = Binding.prototype.ftruncate;
  * @param {number} uid User id.
  * @param {number} gid Group id.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.chown = function(pathname, uid, gid, callback, ctx) {
+Binding.prototype.chown = function (pathname, uid, gid, callback, ctx) {
   markSyscall(ctx, 'chown');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const item = this._system.getItem(pathname);
     if (!item) {
@@ -973,12 +984,13 @@ Binding.prototype.chown = function(pathname, uid, gid, callback, ctx) {
  * @param {number} uid User id.
  * @param {number} gid Group id.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.fchown = function(fd, uid, gid, callback, ctx) {
+Binding.prototype.fchown = function (fd, uid, gid, callback, ctx) {
   markSyscall(ctx, 'fchown');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     item.setUid(uid);
@@ -991,12 +1003,13 @@ Binding.prototype.fchown = function(fd, uid, gid, callback, ctx) {
  * @param {string} pathname Path.
  * @param {number} mode Mode.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.chmod = function(pathname, mode, callback, ctx) {
+Binding.prototype.chmod = function (pathname, mode, callback, ctx) {
   markSyscall(ctx, 'chmod');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const item = this._system.getItem(pathname);
     if (!item) {
@@ -1011,12 +1024,13 @@ Binding.prototype.chmod = function(pathname, mode, callback, ctx) {
  * @param {number} fd File descriptor.
  * @param {number} mode Mode.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.fchmod = function(fd, mode, callback, ctx) {
+Binding.prototype.fchmod = function (fd, mode, callback, ctx) {
   markSyscall(ctx, 'fchmod');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     item.setMode(mode);
@@ -1027,12 +1041,13 @@ Binding.prototype.fchmod = function(fd, mode, callback, ctx) {
  * Delete a named item.
  * @param {string} pathname Path to item.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.unlink = function(pathname, callback, ctx) {
+Binding.prototype.unlink = function (pathname, callback, ctx) {
   markSyscall(ctx, 'unlink');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const item = this._system.getItem(pathname);
     if (!item) {
@@ -1052,12 +1067,13 @@ Binding.prototype.unlink = function(pathname, callback, ctx) {
  * @param {number} atime Access time (in seconds).
  * @param {number} mtime Modification time (in seconds).
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.utimes = function(pathname, atime, mtime, callback, ctx) {
+Binding.prototype.utimes = function (pathname, atime, mtime, callback, ctx) {
   markSyscall(ctx, 'utimes');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const item = this._system.getItem(pathname);
     if (!item) {
@@ -1074,12 +1090,13 @@ Binding.prototype.utimes = function(pathname, atime, mtime, callback, ctx) {
  * @param {number} atime Access time (in seconds).
  * @param {number} mtime Modification time (in seconds).
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.futimes = function(fd, atime, mtime, callback, ctx) {
+Binding.prototype.futimes = function (fd, atime, mtime, callback, ctx) {
   markSyscall(ctx, 'futimes');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     const descriptor = this.getDescriptorById(fd);
     const item = descriptor.getItem();
     item.setATime(new Date(atime * 1000));
@@ -1091,12 +1108,13 @@ Binding.prototype.futimes = function(fd, atime, mtime, callback, ctx) {
  * Synchronize in-core state with storage device.
  * @param {number} fd File descriptor.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.fsync = function(fd, callback, ctx) {
+Binding.prototype.fsync = function (fd, callback, ctx) {
   markSyscall(ctx, 'fsync');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     this.getDescriptorById(fd);
   });
 };
@@ -1105,12 +1123,13 @@ Binding.prototype.fsync = function(fd, callback, ctx) {
  * Synchronize in-core metadata state with storage device.
  * @param {number} fd File descriptor.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.fdatasync = function(fd, callback, ctx) {
+Binding.prototype.fdatasync = function (fd, callback, ctx) {
   markSyscall(ctx, 'fdatasync');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     this.getDescriptorById(fd);
   });
 };
@@ -1120,12 +1139,13 @@ Binding.prototype.fdatasync = function(fd, callback, ctx) {
  * @param {string} srcPath The existing file.
  * @param {string} destPath The new link to create.
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.link = function(srcPath, destPath, callback, ctx) {
+Binding.prototype.link = function (srcPath, destPath, callback, ctx) {
   markSyscall(ctx, 'link');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     srcPath = deBuffer(srcPath);
     destPath = deBuffer(destPath);
     const item = this._system.getItem(srcPath);
@@ -1155,12 +1175,13 @@ Binding.prototype.link = function(srcPath, destPath, callback, ctx) {
  * @param {string} destPath Path for the generated link.
  * @param {string} type Ignored (used for Windows only).
  * @param {function(Error)} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.symlink = function(srcPath, destPath, type, callback, ctx) {
+Binding.prototype.symlink = function (srcPath, destPath, type, callback, ctx) {
   markSyscall(ctx, 'symlink');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     srcPath = deBuffer(srcPath);
     destPath = deBuffer(destPath);
     if (this._system.getItem(destPath)) {
@@ -1184,10 +1205,10 @@ Binding.prototype.symlink = function(srcPath, destPath, type, callback, ctx) {
  * @param {string} pathname Path to symbolic link.
  * @param {string} encoding The encoding ('utf-8' or 'buffer').
  * @param {function(Error, (string|Buffer))} callback Optional callback.
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {string|Buffer} Symbolic link contents (path to source).
  */
-Binding.prototype.readlink = function(pathname, encoding, callback, ctx) {
+Binding.prototype.readlink = function (pathname, encoding, callback, ctx) {
   if (encoding && typeof encoding !== 'string') {
     // this would not happend in nodejs v10+
     callback = encoding;
@@ -1196,7 +1217,7 @@ Binding.prototype.readlink = function(pathname, encoding, callback, ctx) {
 
   markSyscall(ctx, 'readlink');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     pathname = deBuffer(pathname);
     const link = this._system.getItem(pathname);
     if (!link) {
@@ -1216,21 +1237,22 @@ Binding.prototype.readlink = function(pathname, encoding, callback, ctx) {
 /**
  * Stat an item.
  * @param {string} filepath Path.
+ * @param {boolean} bigint Use BigInt.
  * @param {function(Error, Float64Array|BigUint64Array)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
  * @return {Float64Array|BigUint64Array|undefined} Stats or undefined (if sync).
  */
-Binding.prototype.lstat = function(filepath, bigint, callback, ctx) {
+Binding.prototype.lstat = function (filepath, bigint, callback, ctx) {
   markSyscall(ctx, 'lstat');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     filepath = deBuffer(filepath);
     const item = this._system.getItem(filepath);
     if (!item) {
       throw new FSError('ENOENT', filepath);
     }
     const stats = item.getStats(bigint);
-    fillStats(stats);
+    fillStats(stats, bigint);
     return stats;
   });
 };
@@ -1240,12 +1262,13 @@ Binding.prototype.lstat = function(filepath, bigint, callback, ctx) {
  * @param {string} filepath Path.
  * @param {number} mode Mode.
  * @param {function(Error)} callback Callback (optional).
- * @param {Object} ctx Context object (optional), only for nodejs v10+.
+ * @param {object} ctx Context object (optional), only for nodejs v10+.
+ * @return {*} The return if no callback is provided.
  */
-Binding.prototype.access = function(filepath, mode, callback, ctx) {
+Binding.prototype.access = function (filepath, mode, callback, ctx) {
   markSyscall(ctx, 'access');
 
-  return maybeCallback(normalizeCallback(callback), ctx, this, function() {
+  return maybeCallback(normalizeCallback(callback), ctx, this, function () {
     filepath = deBuffer(filepath);
     let item = this._system.getItem(filepath);
     let links = 0;
@@ -1289,4 +1312,4 @@ Binding.prototype.StatWatcher = notImplemented;
  * Export the binding constructor.
  * @type {function()}
  */
-exports = module.exports = Binding;
+module.exports = Binding;
