@@ -1,14 +1,17 @@
 const realBinding = process.binding('fs');
+
 let storedBinding;
 
 /**
  * Perform action, bypassing mock FS
+ * @param {Function} fn The function.
  * @example
  * // This file exists on the real FS, not on the mocked FS
  * const filePath = '/path/file.json';
  * const data = mock.bypass(() => fs.readFileSync(filePath, 'utf-8'));
+ * @return {*} The return.
  */
-exports = module.exports = function bypass(fn) {
+module.exports = function bypass(fn) {
   if (typeof fn !== 'function') {
     throw new Error(`Must provide a function to perform for mock.bypass()`);
   }
@@ -20,11 +23,11 @@ exports = module.exports = function bypass(fn) {
     result = fn();
     if (result && typeof result.then === 'function') {
       return result.then(
-        r => {
+        (r) => {
           enable();
           return r;
         },
-        err => {
+        (err) => {
           enable();
           throw err;
         }
