@@ -2,11 +2,10 @@
 
 const os = require('os');
 const path = require('path');
-
-const Directory = require('./directory');
-const File = require('./file');
-const {FSError} = require('./error');
-const SymbolicLink = require('./symlink');
+const Directory = require('./directory.js');
+const File = require('./file.js');
+const {FSError} = require('./error.js');
+const SymbolicLink = require('./symlink.js');
 
 const isWindows = process.platform === 'win32';
 
@@ -34,12 +33,12 @@ function getPathParts(filepath) {
 
 /**
  * Create a new file system.
- * @param {Object} options Any filesystem options.
+ * @param {object} options Any filesystem options.
  * @param {boolean} options.createCwd Create a directory for `process.cwd()`
  *     (defaults to `true`).
  * @param {boolean} options.createTmp Create a directory for `os.tmpdir()`
  *     (defaults to `true`).
- * @constructor
+ * @class
  */
 function FileSystem(options) {
   options = options || {};
@@ -59,7 +58,7 @@ function FileSystem(options) {
     defaults.push((os.tmpdir && os.tmpdir()) || os.tmpDir());
   }
 
-  defaults.forEach(function(dir) {
+  defaults.forEach(function (dir) {
     const parts = getPathParts(dir);
     let directory = root;
     for (let i = 0, ii = parts.length; i < ii; ++i) {
@@ -86,7 +85,7 @@ function FileSystem(options) {
  * Get the root directory.
  * @return {Directory} The root directory.
  */
-FileSystem.prototype.getRoot = function() {
+FileSystem.prototype.getRoot = function () {
   return this._root;
 };
 
@@ -95,7 +94,7 @@ FileSystem.prototype.getRoot = function() {
  * @param {string} filepath Path to item.
  * @return {Item} The item (or null if not found).
  */
-FileSystem.prototype.getItem = function(filepath) {
+FileSystem.prototype.getItem = function (filepath) {
   const parts = getPathParts(filepath);
   const currentParts = getPathParts(process.cwd());
   let item = this._root;
@@ -135,7 +134,7 @@ FileSystem.prototype.getItem = function(filepath) {
  * Populate a directory with an item.
  * @param {Directory} directory The directory to populate.
  * @param {string} name The name of the item.
- * @param {string|Buffer|function|Object} obj Instructions for creating the
+ * @param {string | Buffer | Function | object} obj Instructions for creating the
  *     item.
  */
 function populate(directory, name, obj) {
@@ -173,15 +172,15 @@ function populate(directory, name, obj) {
 
 /**
  * Configure a mock file system.
- * @param {Object} paths Config object.
- * @param {Object} options Any filesystem options.
+ * @param {object} paths Config object.
+ * @param {object} options Any filesystem options.
  * @param {boolean} options.createCwd Create a directory for `process.cwd()`
  *     (defaults to `true`).
  * @param {boolean} options.createTmp Create a directory for `os.tmpdir()`
  *     (defaults to `true`).
  * @return {FileSystem} Mock file system.
  */
-FileSystem.create = function(paths, options) {
+FileSystem.create = function (paths, options) {
   const system = new FileSystem(options);
 
   for (const filepath in paths) {
@@ -206,12 +205,12 @@ FileSystem.create = function(paths, options) {
 
 /**
  * Generate a factory for new files.
- * @param {Object} config File config.
+ * @param {object} config File config.
  * @return {function():File} Factory that creates a new file.
  */
-FileSystem.file = function(config) {
+FileSystem.file = function (config) {
   config = config || {};
-  return function() {
+  return function () {
     const file = new File();
     if (config.hasOwnProperty('content')) {
       file.setContent(config.content);
@@ -245,12 +244,12 @@ FileSystem.file = function(config) {
 
 /**
  * Generate a factory for new symbolic links.
- * @param {Object} config File config.
+ * @param {object} config File config.
  * @return {function():File} Factory that creates a new symbolic link.
  */
-FileSystem.symlink = function(config) {
+FileSystem.symlink = function (config) {
   config = config || {};
-  return function() {
+  return function () {
     const link = new SymbolicLink();
     if (config.hasOwnProperty('mode')) {
       link.setMode(config.mode);
@@ -286,12 +285,12 @@ FileSystem.symlink = function(config) {
 
 /**
  * Generate a factory for new directories.
- * @param {Object} config File config.
+ * @param {object} config File config.
  * @return {function():Directory} Factory that creates a new directory.
  */
-FileSystem.directory = function(config) {
+FileSystem.directory = function (config) {
   config = config || {};
-  return function() {
+  return function () {
     const dir = new Directory();
     if (config.hasOwnProperty('mode')) {
       dir.setMode(config.mode);
@@ -325,8 +324,9 @@ FileSystem.directory = function(config) {
 
 /**
  * Module exports.
- * @type {function}
+ * @type {Function}
  */
-exports = module.exports = FileSystem;
+module.exports = FileSystem;
+exports = module.exports;
 exports.getPathParts = getPathParts;
 exports.toNamespacedPath = toNamespacedPath;
