@@ -1,23 +1,23 @@
 'use strict';
 
-const Binding = require('./binding');
-const {FSError} = require('./error');
-const FileSystem = require('./filesystem');
+const Binding = require('./binding.js');
+const {FSError} = require('./error.js');
+const FileSystem = require('./filesystem.js');
 const realBinding = process.binding('fs');
 const path = require('path');
-const loader = require('./loader');
-const bypass = require('./bypass');
+const loader = require('./loader.js');
+const bypass = require('./bypass.js');
 const {
   getReadFileContextPrototype,
-  patchReadFileContext
-} = require('./readfilecontext');
+  patchReadFileContext,
+} = require('./readfilecontext.js');
 const fs = require('fs');
 
 const toNamespacedPath = FileSystem.toNamespacedPath;
 
 const realProcessProps = {
   cwd: process.cwd,
-  chdir: process.chdir
+  chdir: process.chdir,
 };
 const realCreateWriteStream = fs.createWriteStream;
 const realStats = realBinding.Stats;
@@ -36,7 +36,7 @@ const realStatWatcher = realBinding.StatWatcher;
  */
 function patch(key) {
   const existingMethod = realBinding[key];
-  realBinding[key] = function() {
+  realBinding[key] = function () {
     if (this._mockedBinding) {
       return this._mockedBinding[key].apply(this._mockedBinding, arguments);
     } else {
@@ -92,7 +92,7 @@ function overrideProcess(cwd, chdir) {
  * When _writev is missing, it will fall back to make multiple _write calls.
  */
 function overrideCreateWriteStream() {
-  fs.createWriteStream = function(path, options) {
+  fs.createWriteStream = function (path, options) {
     const output = realCreateWriteStream(path, options);
     // disable _writev, this will over shadow WriteStream.prototype._writev
     if (realBinding._mockedBinding) {
@@ -128,14 +128,14 @@ function restoreReadFileContext(binding) {
 
 /**
  * Swap out the fs bindings for a mock file system.
- * @param {Object} config Mock file system configuration.
- * @param {Object} options Any filesystem options.
+ * @param {object} config Mock file system configuration.
+ * @param {object} [options={}] Any filesystem options.
  * @param {boolean} options.createCwd Create a directory for `process.cwd()`
  *     (defaults to `true`).
  * @param {boolean} options.createTmp Create a directory for `os.tmpdir()`
  *     (defaults to `true`).
  */
-exports = module.exports = function mock(config, options) {
+module.exports = function mock(config, options = {}) {
   const system = FileSystem.create(config, options);
   const binding = new Binding(system);
 
@@ -166,11 +166,14 @@ exports = module.exports = function mock(config, options) {
   overrideCreateWriteStream();
 };
 
+exports = module.exports;
+
 /**
  * Get hold of the mocked filesystem's 'root'
  * If fs hasn't currently been replaced, this will return an empty object
+ * @return {object} The mock root.
  */
-exports.getMockRoot = function() {
+exports.getMockRoot = function () {
   if (realBinding._mockedBinding) {
     return realBinding._mockedBinding.getSystem().getRoot();
   } else {
@@ -181,7 +184,7 @@ exports.getMockRoot = function() {
 /**
  * Restore the fs bindings for the real file system.
  */
-exports.restore = function() {
+exports.restore = function () {
   restoreBinding();
   restoreProcess();
   restoreCreateWriteStream();
