@@ -1,14 +1,12 @@
 'use strict';
 
 const util = require('util');
-
-const Item = require('./item');
-
+const Item = require('./item.js');
 const constants = require('constants');
 
 /**
  * A directory.
- * @constructor
+ * @class
  */
 function SymbolicLink() {
   Item.call(this);
@@ -25,7 +23,7 @@ util.inherits(SymbolicLink, Item);
  * Set the path to the source.
  * @param {string} pathname Path to source.
  */
-SymbolicLink.prototype.setPath = function(pathname) {
+SymbolicLink.prototype.setPath = function (pathname) {
   this._path = pathname;
 };
 
@@ -33,18 +31,19 @@ SymbolicLink.prototype.setPath = function(pathname) {
  * Get the path to the source.
  * @return {string} Path to source.
  */
-SymbolicLink.prototype.getPath = function() {
+SymbolicLink.prototype.getPath = function () {
   return this._path;
 };
 
 /**
  * Get symbolic link stats.
- * @return {Object} Stats properties.
+ * @param {boolean} bigint Use BigInt.
+ * @return {object} Stats properties.
  */
-SymbolicLink.prototype.getStats = function(bigint) {
+SymbolicLink.prototype.getStats = function (bigint) {
   const size = this._path.length;
   const stats = Item.prototype.getStats.call(this, bigint);
-  const convert = bigint ? v => BigInt(v) : v => v;
+  const convert = bigint ? (v) => BigInt(v) : (v) => v;
 
   stats[1] = convert(this.getMode() | constants.S_IFLNK); // mode
   stats[8] = convert(size); // size
@@ -57,4 +56,4 @@ SymbolicLink.prototype.getStats = function(bigint) {
  * Export the constructor.
  * @type {function()}
  */
-exports = module.exports = SymbolicLink;
+module.exports = SymbolicLink;
