@@ -1,32 +1,32 @@
 'use strict';
 
-const Item = require('../../lib/item');
-const File = require('../../lib/file');
-const assert = require('../helper').assert;
+const Item = require('../../lib/item.js');
+const File = require('../../lib/file.js');
+const assert = require('../helper.js').assert;
 
-describe('File', function() {
-  describe('constructor', function() {
-    it('creates a named file', function() {
+describe('File', function () {
+  describe('constructor', function () {
+    it('creates a named file', function () {
       const file = new File();
       assert.instanceOf(file, File);
       assert.instanceOf(file, Item);
     });
   });
 
-  describe('#getContent()', function() {
-    it('gets the file content', function() {
+  describe('#getContent()', function () {
+    it('gets the file content', function () {
       const file = new File();
       const content = Buffer.from('bar');
       file.setContent(content);
       assert.equal(file.getContent(), content);
     });
 
-    it('is initially empty', function() {
+    it('is initially empty', function () {
       const file = new File();
       assert.equal(String(file.getContent()), '');
     });
 
-    it('updates the atime', function() {
+    it('updates the atime', function () {
       const file = new File();
       file.setContent('bar');
       const old = new Date(1);
@@ -36,8 +36,8 @@ describe('File', function() {
     });
   });
 
-  describe('#setContent()', function() {
-    it('accepts a string', function() {
+  describe('#setContent()', function () {
+    it('accepts a string', function () {
       const file = new File();
       file.setContent('bar');
       const content = file.getContent();
@@ -45,7 +45,7 @@ describe('File', function() {
       assert.equal(String(content), 'bar');
     });
 
-    it('accepts a buffer', function() {
+    it('accepts a buffer', function () {
       const file = new File();
       file.setContent(Buffer.from('baz'));
       const content = file.getContent();
@@ -53,14 +53,14 @@ describe('File', function() {
       assert.equal(String(content), 'baz');
     });
 
-    it('throws for other types', function() {
-      assert.throws(function() {
+    it('throws for other types', function () {
+      assert.throws(function () {
         const file = new File();
         file.setContent(123);
       });
     });
 
-    it('updates the ctime and mtime', function() {
+    it('updates the ctime and mtime', function () {
       const file = new File();
       const old = new Date(1);
       file.setCTime(old);
