@@ -1,29 +1,29 @@
 'use strict';
 
-const helper = require('../helper');
+const helper = require('../helper.js');
 const fs = require('fs');
-const mock = require('../../lib/index');
+const mock = require('../../lib/index.js');
 
 const assert = helper.assert;
 
-describe('fs.createReadStream(path, [options])', function() {
-  beforeEach(function() {
+describe('fs.createReadStream(path, [options])', function () {
+  beforeEach(function () {
     mock({
-      'dir/source': 'source content'
+      'dir/source': 'source content',
     });
   });
   afterEach(mock.restore);
 
-  it('creates a readable stream', function() {
+  it('creates a readable stream', function () {
     const stream = fs.createReadStream('dir/source');
     assert.isTrue(stream.readable);
   });
 
-  it('allows piping to a writable stream', function(done) {
+  it('allows piping to a writable stream', function (done) {
     const input = fs.createReadStream('dir/source');
     const output = fs.createWriteStream('dir/dest');
-    output.on('close', function() {
-      fs.readFile('dir/dest', function(err, data) {
+    output.on('close', function () {
+      fs.readFile('dir/dest', function (err, data) {
         if (err) {
           return done(err);
         }
