@@ -1,22 +1,22 @@
 'use strict';
 
 const Writable = require('stream').Writable;
-const helper = require('../helper');
+const helper = require('../helper.js');
 const fs = require('fs');
-const mock = require('../../lib/index');
+const mock = require('../../lib/index.js');
 
 const assert = helper.assert;
 
-describe('fs.createWriteStream(path[, options])', function() {
-  beforeEach(function() {
+describe('fs.createWriteStream(path[, options])', function () {
+  beforeEach(function () {
     mock();
   });
   afterEach(mock.restore);
 
-  it('provides a write stream for a file in buffered mode', function(done) {
+  it('provides a write stream for a file in buffered mode', function (done) {
     const output = fs.createWriteStream('test.txt');
-    output.on('close', function() {
-      fs.readFile('test.txt', function(err, data) {
+    output.on('close', function () {
+      fs.readFile('test.txt', function (err, data) {
         if (err) {
           return done(err);
         }
@@ -34,10 +34,10 @@ describe('fs.createWriteStream(path[, options])', function() {
     output.end(Buffer.from('content'));
   });
 
-  it('provides a write stream for a file', function(done) {
+  it('provides a write stream for a file', function (done) {
     const output = fs.createWriteStream('test.txt');
-    output.on('close', function() {
-      fs.readFile('test.txt', function(err, data) {
+    output.on('close', function () {
+      fs.readFile('test.txt', function (err, data) {
         if (err) {
           return done(err);
         }
@@ -48,11 +48,11 @@ describe('fs.createWriteStream(path[, options])', function() {
     output.on('error', done);
 
     output.write(Buffer.from('lots '));
-    setTimeout(function() {
+    setTimeout(function () {
       output.write(Buffer.from('of '));
-      setTimeout(function() {
+      setTimeout(function () {
         output.write(Buffer.from('source '));
-        setTimeout(function() {
+        setTimeout(function () {
           output.end(Buffer.from('content'));
         }, 50);
       }, 50);
@@ -60,10 +60,10 @@ describe('fs.createWriteStream(path[, options])', function() {
   });
 
   if (Writable && Writable.prototype.cork) {
-    it('works when write stream is corked', function(done) {
+    it('works when write stream is corked', function (done) {
       const output = fs.createWriteStream('test.txt');
-      output.on('close', function() {
-        fs.readFile('test.txt', function(err, data) {
+      output.on('close', function () {
+        fs.readFile('test.txt', function (err, data) {
           if (err) {
             return done(err);
           }
