@@ -1,8 +1,8 @@
 'use strict';
 
-const helper = require('../helper');
+const helper = require('../helper.js');
 const fs = require('fs');
-const mock = require('../../lib/index');
+const mock = require('../../lib/index.js');
 const path = require('path');
 
 const assert = helper.assert;
@@ -10,18 +10,18 @@ const assert = helper.assert;
 const testParentPerms = process.getuid && process.getgid;
 
 if (fs.mkdtemp) {
-  describe('fs.mkdtemp(prefix[, options], callback)', function() {
-    beforeEach(function() {
+  describe('fs.mkdtemp(prefix[, options], callback)', function () {
+    beforeEach(function () {
       mock({
         parent: {},
         file: 'contents',
-        unwriteable: mock.directory({mode: parseInt('0555', 8)})
+        unwriteable: mock.directory({mode: parseInt('0555', 8)}),
       });
     });
     afterEach(mock.restore);
 
-    it('creates a new directory', function(done) {
-      fs.mkdtemp('parent/dir', function(err, dirPath) {
+    it('creates a new directory', function (done) {
+      fs.mkdtemp('parent/dir', function (err, dirPath) {
         if (err) {
           return done(err);
         }
@@ -33,8 +33,8 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise creates a new directory', function(done) {
-      fs.promises.mkdtemp('parent/dir').then(function(dirPath) {
+    it('promise creates a new directory', function (done) {
+      fs.promises.mkdtemp('parent/dir').then(function (dirPath) {
         const parentPath = path.dirname(dirPath);
         assert.equal(parentPath, 'parent');
         const stats = fs.statSync(dirPath);
@@ -43,8 +43,8 @@ if (fs.mkdtemp) {
       }, done);
     });
 
-    it('accepts a "utf8" encoding argument', function(done) {
-      fs.mkdtemp('parent/dir', 'utf8', function(err, dirPath) {
+    it('accepts a "utf8" encoding argument', function (done) {
+      fs.mkdtemp('parent/dir', 'utf8', function (err, dirPath) {
         if (err) {
           return done(err);
         }
@@ -57,8 +57,8 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise accepts a "utf8" encoding argument', function(done) {
-      fs.promises.mkdtemp('parent/dir', 'utf8').then(function(dirPath) {
+    it('promise accepts a "utf8" encoding argument', function (done) {
+      fs.promises.mkdtemp('parent/dir', 'utf8').then(function (dirPath) {
         assert.isString(dirPath);
         const parentPath = path.dirname(dirPath);
         assert.equal(parentPath, 'parent');
@@ -68,8 +68,8 @@ if (fs.mkdtemp) {
       }, done);
     });
 
-    it('accepts a "buffer" encoding argument', function(done) {
-      fs.mkdtemp('parent/dir', 'buffer', function(err, buffer) {
+    it('accepts a "buffer" encoding argument', function (done) {
+      fs.mkdtemp('parent/dir', 'buffer', function (err, buffer) {
         if (err) {
           return done(err);
         }
@@ -83,8 +83,8 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise accepts a "buffer" encoding argument', function(done) {
-      fs.promises.mkdtemp('parent/dir', 'buffer').then(function(buffer) {
+    it('promise accepts a "buffer" encoding argument', function (done) {
+      fs.promises.mkdtemp('parent/dir', 'buffer').then(function (buffer) {
         assert.instanceOf(buffer, Buffer);
         const dirPath = buffer.toString();
         const parentPath = path.dirname(dirPath);
@@ -95,8 +95,8 @@ if (fs.mkdtemp) {
       }, done);
     });
 
-    it('accepts an options argument with "utf8" encoding', function(done) {
-      fs.mkdtemp('parent/dir', {encoding: 'utf8'}, function(err, dirPath) {
+    it('accepts an options argument with "utf8" encoding', function (done) {
+      fs.mkdtemp('parent/dir', {encoding: 'utf8'}, function (err, dirPath) {
         if (err) {
           return done(err);
         }
@@ -109,10 +109,10 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise accepts an options argument with "utf8" encoding', function(done) {
+    it('promise accepts an options argument with "utf8" encoding', function (done) {
       fs.promises
         .mkdtemp('parent/dir', {encoding: 'utf8'})
-        .then(function(dirPath) {
+        .then(function (dirPath) {
           assert.isString(dirPath);
           const parentPath = path.dirname(dirPath);
           assert.equal(parentPath, 'parent');
@@ -122,8 +122,8 @@ if (fs.mkdtemp) {
         }, done);
     });
 
-    it('accepts an options argument with "buffer" encoding', function(done) {
-      fs.mkdtemp('parent/dir', {encoding: 'buffer'}, function(err, buffer) {
+    it('accepts an options argument with "buffer" encoding', function (done) {
+      fs.mkdtemp('parent/dir', {encoding: 'buffer'}, function (err, buffer) {
         if (err) {
           return done(err);
         }
@@ -137,10 +137,10 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise accepts an options argument with "buffer" encoding', function(done) {
+    it('promise accepts an options argument with "buffer" encoding', function (done) {
       fs.promises
         .mkdtemp('parent/dir', {encoding: 'buffer'})
-        .then(function(buffer) {
+        .then(function (buffer) {
           assert.instanceOf(buffer, Buffer);
           const dirPath = buffer.toString();
           const parentPath = path.dirname(dirPath);
@@ -151,8 +151,8 @@ if (fs.mkdtemp) {
         }, done);
     });
 
-    it('fails if parent does not exist', function(done) {
-      fs.mkdtemp('unknown/child', function(err, dirPath) {
+    it('fails if parent does not exist', function (done) {
+      fs.mkdtemp('unknown/child', function (err, dirPath) {
         if (!err || dirPath) {
           done(new Error('Expected failure'));
         } else {
@@ -164,12 +164,12 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise fails if parent does not exist', function(done) {
+    it('promise fails if parent does not exist', function (done) {
       fs.promises.mkdtemp('unknown/child').then(
-        function() {
+        function () {
           done(new Error('should not succeed.'));
         },
-        function(err) {
+        function (err) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'ENOENT');
           done();
@@ -177,8 +177,8 @@ if (fs.mkdtemp) {
       );
     });
 
-    it('fails if parent is a file', function(done) {
-      fs.mkdtemp('file/child', function(err, dirPath) {
+    it('fails if parent is a file', function (done) {
+      fs.mkdtemp('file/child', function (err, dirPath) {
         if (!err || dirPath) {
           done(new Error('Expected failure'));
         } else {
@@ -190,12 +190,12 @@ if (fs.mkdtemp) {
       });
     });
 
-    it('promise fails if parent is a file', function(done) {
+    it('promise fails if parent is a file', function (done) {
       fs.promises.mkdtemp('file/child').then(
-        function() {
+        function () {
           done(new Error('should not succeed.'));
         },
-        function(err) {
+        function (err) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'ENOTDIR');
           done();
@@ -204,8 +204,8 @@ if (fs.mkdtemp) {
     });
 
     if (testParentPerms) {
-      it('fails if parent is not writeable', function(done) {
-        fs.mkdtemp('unwriteable/child', function(err, dirPath) {
+      it('fails if parent is not writeable', function (done) {
+        fs.mkdtemp('unwriteable/child', function (err, dirPath) {
           if (!err || dirPath) {
             done(new Error('Expected failure'));
           } else {
@@ -217,12 +217,12 @@ if (fs.mkdtemp) {
         });
       });
 
-      it('promise fails if parent is not writeable', function(done) {
+      it('promise fails if parent is not writeable', function (done) {
         fs.promises.mkdtemp('unwriteable/child').then(
-          function() {
+          function () {
             done(new Error('should not succeed.'));
           },
-          function(err) {
+          function (err) {
             assert.instanceOf(err, Error);
             assert.equal(err.code, 'EACCES');
             done();
@@ -234,17 +234,17 @@ if (fs.mkdtemp) {
 }
 
 if (fs.mkdtempSync) {
-  describe('fs.mkdtempSync(prefix[, options])', function() {
-    beforeEach(function() {
+  describe('fs.mkdtempSync(prefix[, options])', function () {
+    beforeEach(function () {
       mock({
         parent: {},
         file: 'contents',
-        unwriteable: mock.directory({mode: parseInt('0555', 8)})
+        unwriteable: mock.directory({mode: parseInt('0555', 8)}),
       });
     });
     afterEach(mock.restore);
 
-    it('creates a new directory', function() {
+    it('creates a new directory', function () {
       const dirPath = fs.mkdtempSync('parent/dir');
       const parentPath = path.dirname(dirPath);
       assert.equal(parentPath, 'parent');
@@ -252,7 +252,7 @@ if (fs.mkdtempSync) {
       assert.isTrue(stats.isDirectory());
     });
 
-    it('accepts a "utf8" encoding argument', function() {
+    it('accepts a "utf8" encoding argument', function () {
       const dirPath = fs.mkdtempSync('parent/dir', 'utf8');
       assert.isString(dirPath);
       const parentPath = path.dirname(dirPath);
@@ -261,7 +261,7 @@ if (fs.mkdtempSync) {
       assert.isTrue(stats.isDirectory());
     });
 
-    it('accepts a "buffer" encoding argument', function() {
+    it('accepts a "buffer" encoding argument', function () {
       const buffer = fs.mkdtempSync('parent/dir', 'buffer');
       assert.instanceOf(buffer, Buffer);
       const dirPath = buffer.toString();
@@ -271,7 +271,7 @@ if (fs.mkdtempSync) {
       assert.isTrue(stats.isDirectory());
     });
 
-    it('accepts an options argument with "utf8" encoding', function() {
+    it('accepts an options argument with "utf8" encoding', function () {
       const dirPath = fs.mkdtempSync('parent/dir', {encoding: 'utf8'});
       assert.isString(dirPath);
       const parentPath = path.dirname(dirPath);
@@ -280,7 +280,7 @@ if (fs.mkdtempSync) {
       assert.isTrue(stats.isDirectory());
     });
 
-    it('accepts an options argument with "buffer" encoding', function() {
+    it('accepts an options argument with "buffer" encoding', function () {
       const buffer = fs.mkdtempSync('parent/dir', {encoding: 'buffer'});
       assert.instanceOf(buffer, Buffer);
       const dirPath = buffer.toString();
@@ -290,21 +290,21 @@ if (fs.mkdtempSync) {
       assert.isTrue(stats.isDirectory());
     });
 
-    it('fails if parent does not exist', function() {
-      assert.throws(function() {
+    it('fails if parent does not exist', function () {
+      assert.throws(function () {
         fs.mkdtempSync('unknown/child');
       });
     });
 
-    it('fails if parent is a file', function() {
-      assert.throws(function() {
+    it('fails if parent is a file', function () {
+      assert.throws(function () {
         fs.mkdtempSync('file/child');
       });
     });
 
     if (testParentPerms) {
-      it('fails if parent is not writeable', function() {
-        assert.throws(function() {
+      it('fails if parent is not writeable', function () {
+        assert.throws(function () {
           fs.mkdtempSync('unwriteable/child');
         });
       });
