@@ -1,24 +1,24 @@
 'use strict';
 
-const helper = require('../helper');
+const helper = require('../helper.js');
 const fs = require('fs');
 const path = require('path');
-const mock = require('../../lib/index');
+const mock = require('../../lib/index.js');
 
 const assert = helper.assert;
 const assertEqualPaths = helper.assertEqualPaths;
 
-describe('fs.realpath(path, [cache], callback)', function() {
-  beforeEach(function() {
+describe('fs.realpath(path, [cache], callback)', function () {
+  beforeEach(function () {
     mock({
       'dir/file.txt': 'content',
-      link: mock.symlink({path: './dir/file.txt'})
+      link: mock.symlink({path: './dir/file.txt'}),
     });
   });
   afterEach(mock.restore);
 
-  it('resolves the real path for a symbolic link', function(done) {
-    fs.realpath('link', function(err, resolved) {
+  it('resolves the real path for a symbolic link', function (done) {
+    fs.realpath('link', function (err, resolved) {
       if (err) {
         return done(err);
       }
@@ -27,15 +27,15 @@ describe('fs.realpath(path, [cache], callback)', function() {
     });
   });
 
-  it('promise resolves the real path for a symbolic link', function(done) {
-    fs.promises.realpath('link').then(function(resolved) {
+  it('promise resolves the real path for a symbolic link', function (done) {
+    fs.promises.realpath('link').then(function (resolved) {
       assertEqualPaths(resolved, path.resolve('dir/file.txt'));
       done();
     }, done);
   });
 
-  it('resolves the real path regular file', function(done) {
-    fs.realpath('dir/file.txt', function(err, resolved) {
+  it('resolves the real path regular file', function (done) {
+    fs.realpath('dir/file.txt', function (err, resolved) {
       if (err) {
         return done(err);
       }
@@ -44,27 +44,27 @@ describe('fs.realpath(path, [cache], callback)', function() {
     });
   });
 
-  it('promise resolves the real path regular file', function(done) {
-    fs.promises.realpath('dir/file.txt').then(function(resolved) {
+  it('promise resolves the real path regular file', function (done) {
+    fs.promises.realpath('dir/file.txt').then(function (resolved) {
       assertEqualPaths(resolved, path.resolve('dir/file.txt'));
       done();
     }, done);
   });
 
-  it('fails on file not exist', function(done) {
-    fs.realpath('bogus', function(err, resolved) {
+  it('fails on file not exist', function (done) {
+    fs.realpath('bogus', function (err, resolved) {
       assert.instanceOf(err, Error);
       assert.equal(err.code, 'ENOENT');
       done();
     });
   });
 
-  it('promise fails on file not exist', function(done) {
+  it('promise fails on file not exist', function (done) {
     fs.promises.realpath('bogus').then(
-      function() {
+      function () {
         done(new Error('should not succeed.'));
       },
-      function(err) {
+      function (err) {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'ENOENT');
         done();
@@ -74,17 +74,17 @@ describe('fs.realpath(path, [cache], callback)', function() {
 });
 
 if (fs.realpath.native) {
-  describe('fs.realpath.native(path, [cache], callback)', function() {
-    beforeEach(function() {
+  describe('fs.realpath.native(path, [cache], callback)', function () {
+    beforeEach(function () {
       mock({
         'dir/file.txt': 'content',
-        link: mock.symlink({path: './dir/file.txt'})
+        link: mock.symlink({path: './dir/file.txt'}),
       });
     });
     afterEach(mock.restore);
 
-    it('resolves the real path for a symbolic link', function(done) {
-      fs.realpath.native('link', function(err, resolved) {
+    it('resolves the real path for a symbolic link', function (done) {
+      fs.realpath.native('link', function (err, resolved) {
         if (err) {
           return done(err);
         }
@@ -93,8 +93,8 @@ if (fs.realpath.native) {
       });
     });
 
-    it('resolves the real path regular file', function(done) {
-      fs.realpath.native('dir/file.txt', function(err, resolved) {
+    it('resolves the real path regular file', function (done) {
+      fs.realpath.native('dir/file.txt', function (err, resolved) {
         if (err) {
           return done(err);
         }
@@ -103,8 +103,8 @@ if (fs.realpath.native) {
       });
     });
 
-    it('fails on file not exist', function(done) {
-      fs.realpath.native('bogus', function(err, resolved) {
+    it('fails on file not exist', function (done) {
+      fs.realpath.native('bogus', function (err, resolved) {
         assert.instanceOf(err, Error);
         assert.equal(err.code, 'ENOENT');
         done();
@@ -113,54 +113,54 @@ if (fs.realpath.native) {
   });
 }
 
-describe('fs.realpathSync(path, [cache])', function() {
-  beforeEach(function() {
+describe('fs.realpathSync(path, [cache])', function () {
+  beforeEach(function () {
     mock({
       'dir/file.txt': 'content',
-      link: mock.symlink({path: './dir/file.txt'})
+      link: mock.symlink({path: './dir/file.txt'}),
     });
   });
   afterEach(mock.restore);
 
-  it('resolves the real path for a symbolic link', function() {
+  it('resolves the real path for a symbolic link', function () {
     const resolved = fs.realpathSync('link');
     assertEqualPaths(resolved, path.resolve('dir/file.txt'));
   });
 
-  it('resolves the real path regular file', function() {
+  it('resolves the real path regular file', function () {
     const resolved = fs.realpathSync('dir/file.txt');
     assertEqualPaths(resolved, path.resolve('dir/file.txt'));
   });
 
-  it('fails on file not exist', function() {
-    assert.throws(function() {
+  it('fails on file not exist', function () {
+    assert.throws(function () {
       fs.realpathSync('bogus');
     });
   });
 });
 
 if (fs.realpathSync.native) {
-  describe('fs.realpathSync.native(path, [cache])', function() {
-    beforeEach(function() {
+  describe('fs.realpathSync.native(path, [cache])', function () {
+    beforeEach(function () {
       mock({
         'dir/file.txt': 'content',
-        link: mock.symlink({path: './dir/file.txt'})
+        link: mock.symlink({path: './dir/file.txt'}),
       });
     });
     afterEach(mock.restore);
 
-    it('resolves the real path for a symbolic link', function() {
+    it('resolves the real path for a symbolic link', function () {
       const resolved = fs.realpathSync.native('link');
       assertEqualPaths(resolved, path.resolve('dir/file.txt'));
     });
 
-    it('resolves the real path regular file', function() {
+    it('resolves the real path regular file', function () {
       const resolved = fs.realpathSync.native('dir/file.txt');
       assertEqualPaths(resolved, path.resolve('dir/file.txt'));
     });
 
-    it('fails on file not exist', function() {
-      assert.throws(function() {
+    it('fails on file not exist', function () {
+      assert.throws(function () {
         fs.realpathSync.native('bogus');
       });
     });
