@@ -1,23 +1,23 @@
 'use strict';
 
-const helper = require('../helper');
+const helper = require('../helper.js');
 const fs = require('fs');
-const mock = require('../../lib/index');
+const mock = require('../../lib/index.js');
 
 const assert = helper.assert;
 
-describe('fs.write(fd, buffer, offset, length, position, callback)', function() {
-  beforeEach(function() {
+describe('fs.write(fd, buffer, offset, length, position, callback)', function () {
+  beforeEach(function () {
     mock({
-      'path/to/file.txt': 'file content'
+      'path/to/file.txt': 'file content',
     });
   });
   afterEach(mock.restore);
 
-  it('writes a buffer to a file', function(done) {
+  it('writes a buffer to a file', function (done) {
     const fd = fs.openSync('path/new-file.txt', 'w');
     const buffer = Buffer.from('new file');
-    fs.write(fd, buffer, 0, buffer.length, null, function(err, written, buf) {
+    fs.write(fd, buffer, 0, buffer.length, null, function (err, written, buf) {
       if (err) {
         return done(err);
       }
@@ -28,14 +28,14 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('promise writes a buffer to a file', function(done) {
+  it('promise writes a buffer to a file', function (done) {
     const buffer = Buffer.from('new file');
     fs.promises
       .open('path/new-file.txt', 'w')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(buffer, 0, buffer.length);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 8);
         assert.equal(result.buffer, buffer);
         assert.equal(String(fs.readFileSync('path/new-file.txt')), 'new file');
@@ -43,10 +43,10 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
       }, done);
   });
 
-  it('writes a buffer to a file with implicit offset, length, position', function(done) {
+  it('writes a buffer to a file with implicit offset, length, position', function (done) {
     const fd = fs.openSync('path/new-file.txt', 'w');
     const buffer = Buffer.from('new file');
-    fs.write(fd, buffer, function(err, written, buf) {
+    fs.write(fd, buffer, function (err, written, buf) {
       if (err) {
         return done(err);
       }
@@ -57,14 +57,14 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('promise writes a buffer to a file with implicit offset, length, position', function(done) {
+  it('promise writes a buffer to a file with implicit offset, length, position', function (done) {
     const buffer = Buffer.from('new file');
     fs.promises
       .open('path/new-file.txt', 'w')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(buffer);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 8);
         assert.equal(result.buffer, buffer);
         assert.equal(String(fs.readFileSync('path/new-file.txt')), 'new file');
@@ -72,13 +72,13 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
       }, done);
   });
 
-  it('can write a portion of a buffer to a file', function(done) {
-    fs.open('path/new-file.txt', 'w', function(err, fd) {
+  it('can write a portion of a buffer to a file', function (done) {
+    fs.open('path/new-file.txt', 'w', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.from('new file');
-      fs.write(fd, buffer, 1, 5, null, function(err2, written, buf) {
+      fs.write(fd, buffer, 1, 5, null, function (err2, written, buf) {
         if (err2) {
           return done(err2);
         }
@@ -90,14 +90,14 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('promise can write a portion of a buffer to a file', function(done) {
+  it('promise can write a portion of a buffer to a file', function (done) {
     const buffer = Buffer.from('new file');
     fs.promises
       .open('path/new-file.txt', 'w')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(buffer, 1, 5);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(result.buffer, buffer);
         assert.equal(String(fs.readFileSync('path/new-file.txt')), 'ew fi');
@@ -105,13 +105,13 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
       }, done);
   });
 
-  it('can write a portion of a buffer to a file position', function(done) {
-    fs.open('path/to/file.txt', 'a', function(err, fd) {
+  it('can write a portion of a buffer to a file position', function (done) {
+    fs.open('path/to/file.txt', 'a', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.from('new file');
-      fs.write(fd, buffer, 1, 5, 2, function(err2, written, buf) {
+      fs.write(fd, buffer, 1, 5, 2, function (err2, written, buf) {
         if (err2) {
           return done(err2);
         }
@@ -126,14 +126,14 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('promise can write a portion of a buffer to a file position', function(done) {
+  it('promise can write a portion of a buffer to a file position', function (done) {
     const buffer = Buffer.from('new file');
     fs.promises
       .open('path/to/file.txt', 'a')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(buffer, 1, 5, 2);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(result.buffer, buffer);
         assert.equal(
@@ -144,13 +144,13 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
       }, done);
   });
 
-  it('can write a portion of a buffer to a file position and enlarge the file', function(done) {
-    fs.open('path/to/file.txt', 'a', function(err, fd) {
+  it('can write a portion of a buffer to a file position and enlarge the file', function (done) {
+    fs.open('path/to/file.txt', 'a', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.from('new file');
-      fs.write(fd, buffer, 1, 5, 8, function(err2, written, buf) {
+      fs.write(fd, buffer, 1, 5, 8, function (err2, written, buf) {
         if (err2) {
           return done(err2);
         }
@@ -165,14 +165,14 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('promise can write a portion of a buffer to a file position and enlarge the file', function(done) {
+  it('promise can write a portion of a buffer to a file position and enlarge the file', function (done) {
     const buffer = Buffer.from('new file');
     fs.promises
       .open('path/to/file.txt', 'a')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(buffer, 1, 5, 8);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(result.buffer, buffer);
         assert.equal(
@@ -183,13 +183,13 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
       }, done);
   });
 
-  it('can append to a file', function(done) {
-    fs.open('path/to/file.txt', 'a', function(err, fd) {
+  it('can append to a file', function (done) {
+    fs.open('path/to/file.txt', 'a', function (err, fd) {
       if (err) {
         return done(err);
       }
       const buffer = Buffer.from(' more');
-      fs.write(fd, buffer, 0, 5, null, function(err2, written, buf) {
+      fs.write(fd, buffer, 0, 5, null, function (err2, written, buf) {
         if (err2) {
           return done(err2);
         }
@@ -204,14 +204,14 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('promise can append to a file', function(done) {
+  it('promise can append to a file', function (done) {
     const buffer = Buffer.from(' more');
     fs.promises
       .open('path/to/file.txt', 'a')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(buffer, 0, 5);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(result.buffer, buffer);
         assert.equal(
@@ -222,12 +222,12 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
       }, done);
   });
 
-  it('fails if file not open for writing', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('fails if file not open for writing', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
-      fs.write(fd, Buffer.from('oops'), 0, 4, null, function(err2) {
+      fs.write(fd, Buffer.from('oops'), 0, 4, null, function (err2) {
         assert.instanceOf(err2, Error);
         assert.equal(err2.code, 'EBADF');
         done();
@@ -235,17 +235,17 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
     });
   });
 
-  it('fails if file not open for writing', function(done) {
+  it('fails if file not open for writing', function (done) {
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(Buffer.from('oops'), 0, 4);
       })
       .then(
-        function() {
+        function () {
           done(new Error('should not succeed.'));
         },
-        function(err) {
+        function (err) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EBADF');
           done();
@@ -254,15 +254,15 @@ describe('fs.write(fd, buffer, offset, length, position, callback)', function()
   });
 });
 
-describe('fs.writeSync(fd, buffer, offset, length, position)', function() {
-  beforeEach(function() {
+describe('fs.writeSync(fd, buffer, offset, length, position)', function () {
+  beforeEach(function () {
     mock({
-      'path/to/file.txt': 'file content'
+      'path/to/file.txt': 'file content',
     });
   });
   afterEach(mock.restore);
 
-  it('writes a buffer to a file', function() {
+  it('writes a buffer to a file', function () {
     const buffer = Buffer.from('new file');
     const fd = fs.openSync('path/new-file.txt', 'w');
     const written = fs.writeSync(fd, buffer, 0, buffer.length);
@@ -270,7 +270,7 @@ describe('fs.writeSync(fd, buffer, offset, length, position)', function() {
     assert.equal(String(fs.readFileSync('path/new-file.txt')), 'new file');
   });
 
-  it('can write a portion of a buffer to a file', function() {
+  it('can write a portion of a buffer to a file', function () {
     const buffer = Buffer.from('new file');
     const fd = fs.openSync('path/new-file.txt', 'w');
     const written = fs.writeSync(fd, buffer, 1, 5);
@@ -278,7 +278,7 @@ describe('fs.writeSync(fd, buffer, offset, length, position)', function() {
     assert.equal(String(fs.readFileSync('path/new-file.txt')), 'ew fi');
   });
 
-  it('can append to a file', function() {
+  it('can append to a file', function () {
     const buffer = Buffer.from(' more');
     const fd = fs.openSync('path/to/file.txt', 'a');
     const written = fs.writeSync(fd, buffer, 0, 5);
@@ -289,29 +289,29 @@ describe('fs.writeSync(fd, buffer, offset, length, position)', function() {
     );
   });
 
-  it('fails if file not open for writing', function() {
+  it('fails if file not open for writing', function () {
     const fd = fs.openSync('path/to/file.txt', 'r');
-    assert.throws(function() {
+    assert.throws(function () {
       fs.writeSync(fd, Buffer.from('oops'), 0, 4);
     });
   });
 });
 
-describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
-  beforeEach(function() {
+describe('fs.write(fd, data[, position[, encoding]], callback)', function () {
+  beforeEach(function () {
     mock({
-      'path/to/file.txt': 'file content'
+      'path/to/file.txt': 'file content',
     });
   });
   afterEach(mock.restore);
 
-  it('writes a string to a file', function(done) {
-    fs.open('path/new-file.txt', 'w', function(err, fd) {
+  it('writes a string to a file', function (done) {
+    fs.open('path/new-file.txt', 'w', function (err, fd) {
       if (err) {
         return done(err);
       }
       const string = 'new file';
-      fs.write(fd, string, null, 'utf-8', function(err2, written, str) {
+      fs.write(fd, string, null, 'utf-8', function (err2, written, str) {
         if (err2) {
           return done(err2);
         }
@@ -323,14 +323,14 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
     });
   });
 
-  it('promise writes a string to a file', function(done) {
+  it('promise writes a string to a file', function (done) {
     const string = 'new file';
     fs.promises
       .open('path/new-file.txt', 'w')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(string, null, 'utf-8');
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 8);
         assert.equal(String(result.buffer), string);
         assert.equal(String(fs.readFileSync('path/new-file.txt')), 'new file');
@@ -338,13 +338,13 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
       }, done);
   });
 
-  it('writes a string to a file with implicit position and encoding', function(done) {
-    fs.open('path/new-file.txt', 'w', function(err, fd) {
+  it('writes a string to a file with implicit position and encoding', function (done) {
+    fs.open('path/new-file.txt', 'w', function (err, fd) {
       if (err) {
         return done(err);
       }
       const string = 'new file';
-      fs.write(fd, string, function(err2, written, str) {
+      fs.write(fd, string, function (err2, written, str) {
         if (err2) {
           return done(err2);
         }
@@ -356,14 +356,14 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
     });
   });
 
-  it('promise writes a string to a file with implicit position and encoding', function(done) {
+  it('promise writes a string to a file with implicit position and encoding', function (done) {
     const string = 'new file';
     fs.promises
       .open('path/new-file.txt', 'w')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(string);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 8);
         assert.equal(String(result.buffer), string);
         assert.equal(String(fs.readFileSync('path/new-file.txt')), 'new file');
@@ -371,13 +371,13 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
       }, done);
   });
 
-  it('can append to a file', function(done) {
-    fs.open('path/to/file.txt', 'a', function(err, fd) {
+  it('can append to a file', function (done) {
+    fs.open('path/to/file.txt', 'a', function (err, fd) {
       if (err) {
         return done(err);
       }
       const string = ' more';
-      fs.write(fd, string, null, 'utf-8', function(err2, written, str) {
+      fs.write(fd, string, null, 'utf-8', function (err2, written, str) {
         if (err2) {
           return done(err2);
         }
@@ -389,14 +389,14 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
     });
   });
 
-  it('promise can append to a file', function(done) {
+  it('promise can append to a file', function (done) {
     const string = ' more';
     fs.promises
       .open('path/to/file.txt', 'a')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(string);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(String(result.buffer), string);
         assert.equal(
@@ -407,13 +407,13 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
       }, done);
   });
 
-  it('can write to a position of a file', function(done) {
-    fs.open('path/to/file.txt', 'a', function(err, fd) {
+  it('can write to a position of a file', function (done) {
+    fs.open('path/to/file.txt', 'a', function (err, fd) {
       if (err) {
         return done(err);
       }
       const string = ' more';
-      fs.write(fd, string, 3, function(err2, written, str) {
+      fs.write(fd, string, 3, function (err2, written, str) {
         if (err2) {
           return done(err2);
         }
@@ -425,14 +425,14 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
     });
   });
 
-  it('promise can write to a position of a file', function(done) {
+  it('promise can write to a position of a file', function (done) {
     const string = ' more';
     fs.promises
       .open('path/to/file.txt', 'a')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(string, 3);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(String(result.buffer), string);
         assert.equal(
@@ -443,13 +443,13 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
       }, done);
   });
 
-  it('can write to a position of a file and enlarge it', function(done) {
-    fs.open('path/to/file.txt', 'a', function(err, fd) {
+  it('can write to a position of a file and enlarge it', function (done) {
+    fs.open('path/to/file.txt', 'a', function (err, fd) {
       if (err) {
         return done(err);
       }
       const string = ' more';
-      fs.write(fd, string, 9, function(err2, written, str) {
+      fs.write(fd, string, 9, function (err2, written, str) {
         if (err2) {
           return done(err2);
         }
@@ -461,14 +461,14 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
     });
   });
 
-  it('promise can write to a position of a file and enlarge it', function(done) {
+  it('promise can write to a position of a file and enlarge it', function (done) {
     const string = ' more';
     fs.promises
       .open('path/to/file.txt', 'a')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write(string, 9);
       })
-      .then(function(result) {
+      .then(function (result) {
         assert.equal(result.bytesWritten, 5);
         assert.equal(String(result.buffer), string);
         assert.equal(
@@ -479,29 +479,29 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
       }, done);
   });
 
-  it('fails if file not open for writing', function(done) {
-    fs.open('path/to/file.txt', 'r', function(err, fd) {
+  it('fails if file not open for writing', function (done) {
+    fs.open('path/to/file.txt', 'r', function (err, fd) {
       if (err) {
         return done(err);
       }
-      fs.write(fd, 'oops', null, 'utf-8', function(err2) {
+      fs.write(fd, 'oops', null, 'utf-8', function (err2) {
         assert.instanceOf(err2, Error);
         done();
       });
     });
   });
 
-  it('promise fails if file not open for writing', function(done) {
+  it('promise fails if file not open for writing', function (done) {
     fs.promises
       .open('path/to/file.txt', 'r')
-      .then(function(fd) {
+      .then(function (fd) {
         return fd.write('oops');
       })
       .then(
-        function() {
+        function () {
           done(new Error('should not succeed.'));
         },
-        function(err) {
+        function (err) {
           assert.instanceOf(err, Error);
           assert.equal(err.code, 'EBADF');
           done();
@@ -510,15 +510,15 @@ describe('fs.write(fd, data[, position[, encoding]], callback)', function() {
   });
 });
 
-describe('fs.writeSync(fd, data[, position[, encoding]])', function() {
-  beforeEach(function() {
+describe('fs.writeSync(fd, data[, position[, encoding]])', function () {
+  beforeEach(function () {
     mock({
-      'path/to/file.txt': 'file content'
+      'path/to/file.txt': 'file content',
     });
   });
   afterEach(mock.restore);
 
-  it('writes a string to a file', function() {
+  it('writes a string to a file', function () {
     const fd = fs.openSync('path/new-file.txt', 'w');
     const string = 'new file';
     const written = fs.writeSync(fd, string, null, 'utf-8');
@@ -526,7 +526,7 @@ describe('fs.writeSync(fd, data[, position[, encoding]])', function() {
     assert.equal(fs.readFileSync('path/new-file.txt'), 'new file');
   });
 
-  it('can append to a file', function() {
+  it('can append to a file', function () {
     const fd = fs.openSync('path/to/file.txt', 'a');
     const string = ' more';
     const written = fs.writeSync(fd, string, null, 'utf-8');
@@ -534,9 +534,9 @@ describe('fs.writeSync(fd, data[, position[, encoding]])', function() {
     assert.equal(fs.readFileSync('path/to/file.txt'), 'file content more');
   });
 
-  it('fails if file not open for writing', function() {
+  it('fails if file not open for writing', function () {
     const fd = fs.openSync('path/to/file.txt', 'r');
-    assert.throws(function() {
+    assert.throws(function () {
       fs.writeSync(fd, 'oops', null, 'utf-8');
     });
   });
